# eric7.EricNetwork.EricGoogleMailHelpers

Module implementing some helpers for Google mail.

### Global Attributes

APPLICATION_NAME
CLIENT_SECRET_FILE
RequiredPackages
SCOPES
TOKEN_FILE

### Classes

None

### Functions

getInstallCommand | Module function to get the install command to get the Google mail support activated.
isClientSecretFileAvailable | Module function to check, if the client secret file has been installed.

## getInstallCommand

getInstallCommand()

Module function to get the install command to get the Google mail support activated.

Return:
  install command

Return Type:
  str

Up

## isClientSecretFileAvailable

isClientSecretFileAvailable()

Module function to check, if the client secret file has been installed.

Return:
  flag indicating, that the credentials file is there

Return Type:
  bool

Up